#
# spec file for package python-castellan
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-castellan
Version:        4.3.0
Release:        1.2
Summary:        Generic Key Manager interface for OpenStack
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/castellan
Source0:        https://files.pythonhosted.org/packages/source/c/castellan/castellan-4.3.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-barbicanclient >= 5.5.0
BuildRequires:  python3-cryptography >= 2.7
BuildRequires:  python3-keystoneauth1 >= 3.4.0
BuildRequires:  python3-oslo.config >= 6.4.0
BuildRequires:  python3-oslo.log >= 3.36.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-reno
BuildRequires:  python3-requests >= 2.18.0
BuildRequires:  python3-requests-mock
BuildRequires:  python3-setuptools
BuildRequires:  python3-stestr
BuildRequires:  python3-testscenarios
BuildRequires:  python3-testtools
BuildArch:      noarch

%description
Generic Key Manager interface for OpenStack.

%package -n python3-castellan
Summary:        Generic Key Manager interface for OpenStack
Requires:       python3-Babel
Requires:       python3-barbicanclient >= 5.5.0
Requires:       python3-cryptography >= 2.7
Requires:       python3-keystoneauth1 >= 3.4.0
Requires:       python3-oslo.config >= 6.4.0
Requires:       python3-oslo.context >= 2.19.2
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.log >= 3.36.0
Requires:       python3-oslo.utils >= 3.33.0
Requires:       python3-requests >= 2.18.0
Requires:       python3-stevedore >= 1.20.0

%description -n python3-castellan
Generic Key Manager interface for OpenStack.

This package includes the Python 3.x module.

%package -n python-castellan-doc
Summary:        Documentation for castellan
Group:          Documentation/HTML
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-sphinxcontrib-svg2pdfconverter

%description -n python-castellan-doc
Castellan is a generic Key Manager interface for OpenStack.
This package contains the documentation

%prep
%autosetup -p1 -n castellan-4.3.0
%py_req_cleanup

%build
%{py3_build}
# generate html docs
PBR_VERSION=%{version} %sphinx_build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%check
%{openstack_stestr_run}

%files -n python3-castellan
%license LICENSE
%{python3_sitelib}/castellan
%{python3_sitelib}/*.egg-info

%files -n python-castellan-doc
%license LICENSE
%doc README.rst doc/build/html

%changelog
* Thu Jan  4 2024 cloud-devel@suse.de
- update to version 4.3.0
  - Revert "Implement force parameter"
  - Revert "Moves supported python runtimes from version 3.8 to 3.10"
  - Update master for stable/zed
  - Revert "Add secret consumers documentation and release note"
  - Moves supported python runtimes from version 3.8 to 3.10
  - Initial change to add secret consumers
  - Add Python3 antelope unit tests
  - Revert "Add secret consumers functional tests"
  - Add force parameter functional tests
  - Update master for stable/2023.1
  - Implement force parameter
  - Add support for specifying Vault KV path
  - Add secret consumers
  - Add secret consumers functional tests
  - Add secret consumers documentation and release note
  - Update TOX_CONSTRAINTS_FILE for stable/2023.2
  - Revert "Add secret consumers"
  - Make tests more consistent
  - Fix tox4 error
  - Update .gitreview for stable/2023.2
  - Revert "Add force parameter functional tests"
* Mon Mar  6 2023 cloud-devel@suse.de
- update to version 4.0.0
  - Drop python3.6/3.7 support in testing runtime
* Tue Jun  7 2022 cloud-devel@suse.de
- update to version 3.11.0
  - Add Python3 zed unit tests
  - Add Python3 yoga unit tests
  - Support setting Vault kv version config
  - Update master for stable/yoga
  - Fix gitignore pattern for vault related files
  - Replace the deprecated argument tenant
  - remove unicode from code
  - Remove redundant override of logging_context_format_string
  - Add support for Vault Namespaces
  - Updating python testing classifier as per Yoga testing runtime
  - Update master for stable/xena
* Mon Dec  6 2021 cloud-devel@suse.de
- update to version 3.9.1
  - Move flake8 as a pre-commit local target.
  - Add Python3 xena unit tests
  - setup.cfg: Replace dashes with underscores
  - Changed minversion in tox to 3.18.0
  - Moving IRC network reference to OFTC
  - Allow specifying region of barbican endpoint
  - barbican key manager: Add support for service user
  - Simplify the reference to barbican parameters
  - Update master for stable/wallaby
  - Add missing font for PDF doc generation
  - Remove lower-constraints remnants
* Mon May  3 2021 cloud-devel@suse.de
- update to version 3.7.1
  - Fix assertion typo in barbican key manager unit test
  - Remove six
  - Add Python3 wallaby unit tests
  - Adding pre-commit
  - Update master for stable/victoria
  - Dropping lower constraints testing
  - Don't expect barbican service name to be barbican.
  - Use py3 as the default runtime for tox
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 3.6.0
  - Remove translation sections from setup.cfg
  - Bump vault version
  - Bump default tox env from py37 to py38
  - add "verify_ssl_path" config for barbican key manager
  - Fix hacking min version to 3.0.1
  - Add to_dict and from_dict conversions to managed objects
  - Update lower-constraints versions
  - Add py38 package metadata
  - drop mock from lower-constraints
  - migrate testing to ubuntu focal
  - Update hacking for Python3
  - Add handler for Bad Request error during Vault authentication
  - Replaces _get_api_version with config option
  - Add Python3 victoria unit tests
  - Switch to newer openstackdocstheme and reno versions
  - Update master for stable/ussuri
  - Use 'barbican_endpoint_type'config option to get endpoint from catalog
  - zuul: use the new barbican simple-crypto job
  - Some Cleanups
  - Bump bandit version
  - [goal] Migrate testing to ubuntu focal
  - Use unittest.mock instead of third party mock
* Tue May 12 2020 cloud-devel@suse.de
- update to version 3.0.1
  - Fix stale references to renamed constant
  - Update master for stable/train
  - Fix "is" usage with literals
  - Implements KeyManager's option discovery.
  - Fix coverage tests
  - Switch to Ussuri jobs
  - Removes context "validation".
  - Add Wiki links to readme
  - PDF Documentation Build tox target
  - Reuse existing token from RequestContext
  - [ussuri][goal] Drop python 2.7 support and testing
  - Moving common objects under KeyManager.
  - Drop use of six
* Thu Mar 12 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only client
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 1.3.1
  - Cap Bandit below 1.6.0 and update Sphinx requirement
  - Replace openstack.org git:// URLs with https://
  - OpenDev Migration Patch
  - List requests as explicit dependency
  - Add bindep.txt
  - Use opendev repository
  - Add Python 3 Train unit tests
  - Update master for stable/stein
  - Dropping the py35 testing
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 1.2.2
  - Bump HashiCorp Vault version for tests.
  - Change openstack-dev to openstack-discuss
  - fix tox python3 overrides
  - Fix Vault K/V API compatibility.
  - Add release note link in README
  - Switch to stestr
  - Add Castellan Oslo Config Driver.
  - Fix length usage in VaultKeyManager.create_key.
  - vault: add AppRole support
  - Update reno for stable/rocky
  - Update min tox version to 2.0
  - Don't quote {posargs} in tox.ini
  - Use template for lower-constraints
  - Add method to wrap HashiCorp Vault HTTP API calls.
  - Set py3 tests according to Stein runtimes.
  - add python 3.6 unit test job
  - vault: support configuration of KV mountpoint
  - add python 3.7 unit test job
  - import zuul job settings from project-config
  - Add code to generate private keys
* Tue Sep 11 2018 cloud-devel@suse.de
- update to version 0.19.0
  - Update UPPER_CONSTRAINTS_FILE for stable/rocky
  - Update .gitreview for stable/rocky
  - import zuul job settings from project-config
  - Add code to generate private keys
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 0.18.0
  - Add config option for Barbican endpoint type
  - Add barbican-tempest experimental job
  - Update unreachable links in contributor document
  - Promote castellan's barbican-tempest-plugin job
  - Update reno for stable/queens
  - Update links in README
  - Zuul: Remove project name
  - pypy is not checked at gate
  - set default python to python3
  - fix list of default virtualenvs
  - Use Zuul v3 fetch-subunit-output
  - Updated from global requirements
  - add lower-constraints job
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Tue Jan 16 2018 cloud-devel@suse.de
- update to version 0.17.0
  - Updated from global requirements
- convert to singlespec
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 0.16.0
  - Add releasenotes for castellan
  - Append a forward slash to the base_url
  - Remove genconfig from functional tests
  - Avoid tox_install.sh for constraints support
  - Replace LOG.warn with LOG.warning
  - Add list capability
  - Include domain info when creating identity token
  - Add ID to managed objects
  - Remove use of tox-siblings role
  - Add a functional vault job
  - Use generic user for both zuul v2 and v3
  - Rename barbican client import
  - Use Stevedore for better extensions
  - Makes list method not abstract
  - Fix retrieving barbican endpoint from service catalog
  - Improve docs around configuring Castellan
  - Remove setting of version/release from releasenotes
  - Support handling legacy all-zeros key ID
  - Vault based key manager
  - Migrate to zuulv3
  - Updated from global requirements
  - allow redirects in .htaccess files on the static web servers
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 0.12.0
  - Correct config path in functional test
  - removed the older version of python
  - Enable some off-by-default checks
  - Remove outdated comment
  - Add ability to get only metadata
  - Add option for verifying TLS (https) requests
  - MockKeyManager should return a copy of the object instead of actual object
  - Fix incorrect config in usage doc
  - Removes unnecessary utf-8 encoding
  - rearrange existing documentation to fit the new standard layout
  - Fix gate failure on pep8
  - Optimize the link address
  - Replacing six.iteritems() with .items()
  - Change keystone endpoint
  - Update docs on config generation
  - Switch from oslosphinx to openstackdocstheme
  - Update the doc URL in the documents
  - Fix error in credential_factory
  - Update .gitignore
  - Enable warning-is-error in doc build
  - Fixes all current typo errors on Castellan project.
  - Remove log translations
  - Replaces uuid.uuid4 with uuidutils.generate_uuid()
  - Updated from global requirements
* Fri Feb 10 2017 cloud-devel@suse.de
- update to version 0.5.0:
  - Cleanup created secrets after functional test
  - Remove tempest plugin from Castellan
  - Cookiecutter commit for Security Tempest plugin
  - Add Python 3.5 classifier and venv for castellan
  - Add keystoneauth to requirements.txt
  - H803 hacking has been removed
  - Remove default=None when set value in Config
  - Add a bandit environment to tox
  - Remove discover from test-requirements
  - Update docs for reading conf files
  - Update doc
  - Show team and repo badges on README
  - Support upper-constraints in tox.ini
  - Enable coverage report in console output
  - Correct castellan reraising of exception
  - Use international logging message
  - Use keystoneauth1 instead of keystoneclient
  - Update .gitignore
  - Update flake8 ignore list
  - MockKeyManager create_key change key_length to length
  - Use generic keystoneauth plugin identity interfaces
  - remove obsolete oslo incubator code
  - Add prefix "$" for command examples
  - Refactor Barbican Key Manager Tests
  - Remove unused requirements
  - Modify the home-page info
  - Updated from global requirements
  - Making sensitive parameters secret to avoid logging
  - Add Barbicanclient dependancy
* Tue Nov 22 2016 tbechtold@suse.com
- Switch to stable/newton
* Thu Sep  8 2016 tbechtold@suse.com
- Update _service and switch to upstream spec template
* Mon Jun 20 2016 dmueller@suse.com
- update to 0.4.0:
  * Add Credential Authentication Usage Documentation
  * Allow Barbican Key Manager to accept different auth credentials
  * Updated from global requirements
  * Add help to Castellan Credential Factory Opts
  * Updated from global requirements
  * Introduce Castellan Credential Factory
  * Updated from global requirements
  * Introduce Castellan Credential Objects
  * Add created property to Managed Objects
  * Update MockKeyManager to use given algorithm
  * Remove functional test dependency on config file
  * Mock key manager takes configuration as an arg
  * Updated from global requirements
  * Clean up removed hacking rule from [flake8] ignore lists
  * Use Keystone V3 Identity Plugins for Functional Tests
  * Updated from global requirements
  * Add logic to error out of key creation if order errors out
  * Update docs with parsing config files
  * Removes MANIFEST.in as it is not needed explicitely by PBR
  * Remove py26 support from castellan
  * Updated from global requirements
  * Move line of code to ensure context and client stay in sync
* Wed Apr 13 2016 dmueller@suse.com
- install license
* Tue Dec 15 2015 dmueller@suse.com
- update to 0.3.1:
  * Add some documentation on enabling logging
  * Allow for default logging configuration to be user enabled
  * Mark castellan as being a universal wheel
  * Add gate hooks for Castellan functional tests
  * Update managed object __eq__ and __ne__
  * Updated from global requirements
  * Add the debug flag to tox.ini
  * Can not set auth_endpoint in runtime
  * Updated from global requirements
  * Allow log statements to be printed out in stdout
  * Add documentation links and fixup README.rst
  * Updated from global requirements
  * Add testing documentation to Castellan
  * Add contributing documentation to Castellan
  * Fix typo and add name to not_implemented and mock key_manager
  * Adds documentation on creating Oslo RequestContext in Castellan
  * Updated from global requirements
  * Add name to Castellan Objects and Barbican Key Manager
  * Fix some spelling typo in manual
  * Updated from global requirements
  * Update Barbican functional tests
  * Add ManagedObjectNotFoundError
  * Change ignore-errors to ignore_errors
  * Standardize Barbican error messages
* Tue Sep 15 2015 tbechtold@suse.com
- Initial packaging (version 0.2.1)
